.. odxtools documentation master file, created by
   sphinx-quickstart on Wed Jun 23 23:03:35 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to odxtools's documentation!
====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. automodule:: odxtools
   :members:
   :undoc-members:

Important classes
=================
      
.. autoclass:: odxtools.database.Database
   :members:
   :undoc-members:
 

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
